FKM.gk (X, k, m, vp, RS, stand, startU, conv, maxit)stand=1, the clustering algorithm is run using standardized data (default: no standardization)U (default: no rational start)fclust, which is a list with the following components:NULL for FKM.gk)RS startsRS startsRS startsNULL for FKM.gk)NULL for FKM.gk)stand=1, No if stand=0)stand=1)Fclust, Fclust.indexdata(unemployment)
## It may take more than a few seconds
clust=FKM.gk(unemployment,k=3,RS=10)Run the code above in your browser using DataLab