FKM.gk.ent (X, k, ent, vp, RS, stand, startU, conv, maxit)stand=1, the clustering algorithm is run using standardized data (default: no standardization)U (default: no rational start)fclust, which is a list with the following components:NULL for FKM.gk.ent)RS startsRS startsRS startsNULL for FKM.gk.ent)NULL for FKM.gk.ent)stand=1, No if stand=0)stand=1)Fclust, Fclust.indexdata(unemployment)
## It may take more than a few seconds
clust=FKM.gk.ent(unemployment,k=3,ent=0.2,RS=10,stand=1)Run the code above in your browser using DataLab