FKM.noise (X, k, m, delta, RS, stand, startU, conv, maxit)FKM using the same values of k and m)stand=1, the clustering algorithm is run using standardized data (default: no standardization)U (default: no rational start)fclust, which is a list with the following components:NULL for FKM.noise)NULL for FKM.noise)RS startsRS startsRS startsNULL for FKM.noise)NULL for FKM.noise)stand=1, No if stand=0)stand=1)Fclust, Fclust.indexdata(butterfly)
clust=FKM.noise(butterfly,RS=5,delta=3)Run the code above in your browser using DataLab